==> hapi-fhir-base-7.0.2-sources.jar: ca/uhn/fhir/context/support/ValidationSupportContext.java <==
/*-
 * #%L
 * HAPI FHIR - Core Library
 * %%
 * Copyright (C) 2014 - 2024 Smile CDR, Inc.
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package ca.uhn.fhir.context.support;

import org.thymeleaf.util.Validate;

import java.util.HashSet;
import java.util.Set;

public class ValidationSupportContext {

	private final IValidationSupport myRootValidationSupport;
	private final Set<String> myCurrentlyGeneratingSnapshots = new HashSet<>();

	public ValidationSupportContext(IValidationSupport theRootValidationSupport) {
		Validate.notNull(theRootValidationSupport, "theRootValidationSupport musty not be null");
		myRootValidationSupport = theRootValidationSupport;
	}

	public IValidationSupport getRootValidationSupport() {
		return myRootValidationSupport;
	}

	public Set<String> getCurrentlyGeneratingSnapshots() {
		return myCurrentlyGeneratingSnapshots;
	}

	public boolean isEnabledValidationForCodingsLogicalAnd() {
		return myRootValidationSupport.isEnabledValidationForCodingsLogicalAnd();
	}
}

==> hapi-fhir-base-8.2.1-sources.jar: ca/uhn/fhir/context/support/ValidationSupportContext.java <==
/*-
 * #%L
 * HAPI FHIR - Core Library
 * %%
 * Copyright (C) 2014 - 2025 Smile CDR, Inc.
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package ca.uhn.fhir.context.support;

import org.thymeleaf.util.Validate;

import java.util.HashSet;
import java.util.Set;

public class ValidationSupportContext {

	private final IValidationSupport myRootValidationSupport;
	private final Set<String> myCurrentlyGeneratingSnapshots = new HashSet<>();

	public ValidationSupportContext(IValidationSupport theRootValidationSupport) {
		Validate.notNull(theRootValidationSupport, "theRootValidationSupport must not be null");
		myRootValidationSupport = theRootValidationSupport;
	}

	public IValidationSupport getRootValidationSupport() {
		return myRootValidationSupport;
	}

	public Set<String> getCurrentlyGeneratingSnapshots() {
		return myCurrentlyGeneratingSnapshots;
	}

	public boolean isCodeableConceptValidationSuccessfulIfNotAllCodingsAreValid() {
		return myRootValidationSupport.isCodeableConceptValidationSuccessfulIfNotAllCodingsAreValid();
	}
}
